From bfa37405f1a9dafd89632b2f0cfd4e56e34ccfff Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <fare@tunes.org>
Date: Sun, 27 Nov 2011 19:09:11 -0500
Subject: [PATCH] 2.018.21: don't use change-class with keys, for the sake of
 genera(!)

---
 asdf.asd  | 2 +-
 asdf.lisp | 7 ++++---
 2 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/asdf.asd b/asdf.asd
index 73088a4f..4d57a78c 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.018.20" ;; to be automatically updated by bin/bump-revision
+  :version "2.018.21" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
diff --git a/asdf.lisp b/asdf.lisp
index 7f2c9bfd..595a2f6b 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
 ;;; This is ASDF 2.018.20: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -107,7 +107,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.018.20")
+         (asdf-version "2.018.21")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -2831,7 +2831,8 @@ Returns the new tree (which probably shares structure with the old one)"
       ret)))
 
 (defun* reset-system (system &rest keys &key &allow-other-keys)
-  (apply 'change-class (change-class system 'proto-system) 'system keys))
+  (change-class (change-class system 'proto-system) 'system)
+  (apply 'reinitialize-instance system keys))
 
 (defun* do-defsystem (name &rest options
                            &key pathname (class 'system)
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
-;;; This is ASDF 2.018.20: Another System Definition Facility.
+;;; This is ASDF 2.018.21: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
-- 
GitLab